<h3 class="mt-3">
    CKAN Helpers
</h3>
<div class="mb-3">
    <i class="fas fa-exclamation-triangle text-warning"></i> - Missing docstring.
</div>
<div>
    <div class="accordion">
        {% for helper in data.helpers %}
        <div class="accordion-item mb-3 border">
            <h2 class="accordion-header" id="helper-{{helper.func_name}}-heading">
              <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#helper-{{helper.func_name}}" aria-expanded="false" aria-controls="helper-{{helper.func_name}}">
                <div class="d-flex">
                    <span class="h4 mb-0">{{ helper.func_name }}</span>
                    {% if not helper.docstring %}
                        <i class="fas fa-exclamation-triangle text-warning ms-2"></i>
                    {% endif %}
                </div>
              </button>
            </h2>
            <div id="helper-{{helper.func_name}}" class="accordion-collapse collapse" aria-labelledby="helper-{{helper.func_name}}-heading">
              <div class="accordion-body">
                <div>
                    <span class="h4">
                        {{ helper.defined }}
                    </span>
                </div>
                {% if helper.docstring %}
                    <pre>{{ helper.docstring }}</pre>
                {% else %}
                    <p>Missing docstring for this Helper.</p>
                {% endif %}
              </div>
            </div>
          </div>
        {% endfor %}
    </div>
</div>
