<h2 class="mt-3">
    System Information
</h2>
<div class="mb-4">
    <table class="table mb-3">
        <thead>
            <tr>
                <th scope="col">System Platform</th>
                <th scope="col">Distribution</th>
                <th scope="col">Python Version</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>{{ data.platform_info.platform }}</td>
                <td>{{ data.platform_info.distro }}</td>
                <td>{{ data.platform_info.python_version }}</td>
            </tr>
        </tbody>
    </table>
</div>
<h2 class="mt-3">
    RAM
</h2>
<div class="mb-4">
    <table class="table mb3">
        <tr>
            <th class="col">{{ _('RAM Usage in') }} %</th>
            <th class="col">{{ _('RAM Usage GB') }}</th>
            <th class="col">{{ _('RAM Total') }}</th>
        </tr>
        <tbody>
            <tr>
                <td>{{ data.ram_usage.precent_usage }}%</td>
                <td>{{ data.ram_usage.used_ram }}GB</td>
                <td>{{ data.ram_usage.total_ram }}GB</td>
            </tr>
        </tbody>
    </table>
</div>
<h2 class="mt-3">
    Disk Space
</h2>
<div class="mb-4">
    <table class="table mb3">
        <tr>
            <th class="col">{{ _('Path') }}</th>
            <th class="col">{{ _('Disk Usage in') }} %</th>
            <th class="col">{{ _('Disk Total') }}</th>
            <th class="col">{{ _('Disk Free') }}</th>
        </tr>
        <tbody>
            {% for disk in data.disk_usage %}
                <tr>
                    <td>{{ disk.path }}</td>
                    <td>{{ disk.precent_usage }}%</td>
                    <td>{{ disk.total_disk }}</td>
                    <td>{{ disk.free_space }}</td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
</div>